"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
var i18n = require("../../vscode/build/lib/i18n");
var fs = require("fs");
var path = require("path");
var vfs = require("vinyl-fs");
function update() {
    var vsCodeStat = fs.statSync('../vscode');
    if (!vsCodeStat || !vsCodeStat.isDirectory) {
        throw new Error('To update, language pack must be placed in the same directory as a current vscode repository');
    }
    var langPackFolder = process.cwd();
    process.chdir('../vscode');
    var packageJSON = JSON.parse(fs.readFileSync(path.join(langPackFolder, 'package.json')).toString());
    var contributes = packageJSON['contributes'];
    if (!contributes || !contributes['languagePack']) {
        throw new Error('Extension must define a "languagePack" contribution in the "package.json"');
    }
    var languagePackInfo = contributes['languagePack'];
    if (!languagePackInfo.languageId) {
        throw new Error('The languagePack contribution must contain at least a "languageId" entry.');
    }
    var server = languagePackInfo.server || 'www.transifex.com';
    var userName = languagePackInfo.userName || 'api';
    var apiToken = process.env.TRANSIFEX_API_TOKEN;
    var languageId = languagePackInfo.languageId;
    var translationDataFolder = path.join(langPackFolder, 'translations');
    i18n.pullBuildXlfFiles(server, userName, apiToken, { id: languageId })
        .pipe(i18n.prepareI18nPackFiles())
        .pipe(vfs.dest(translationDataFolder));
}
update();
