/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/

import * as i18n from '../../vscode/build/lib/i18n';
import * as fs from 'fs';
import * as path from 'path';
import * as vfs from 'vinyl-fs';

function update() {
	const vsCodeStat = fs.statSync('../vscode');
	if (!vsCodeStat || !vsCodeStat.isDirectory) {
		throw new Error('To update, language pack must be placed in the same directory as a current vscode repository');
	}
	let langPackFolder = process.cwd();
	process.chdir('../vscode');

	const packageJSON = JSON.parse(fs.readFileSync(path.join(langPackFolder, 'package.json')).toString());
	const contributes = packageJSON['contributes'];
	if (!contributes || !contributes['languagePack']) {
		throw new Error('Extension must define a "languagePack" contribution in the "package.json"');
	}

	const languagePackInfo = contributes['languagePack'];
	if (!languagePackInfo.languageId) {
		throw new Error('The languagePack contribution must contain at least a "languageId" entry.');
	}	
	
	const server = languagePackInfo.server || 'www.transifex.com';
	const userName = languagePackInfo.userName || 'api';
	const apiToken = process.env.TRANSIFEX_API_TOKEN;
	const languageId = languagePackInfo.languageId;

	let translationDataFolder = path.join(langPackFolder, 'translations');
	i18n.pullBuildXlfFiles(server, userName, apiToken, { id: languageId })
		.pipe(i18n.prepareI18nPackFiles())
		.pipe(vfs.dest(translationDataFolder));
}

update();
